@@ -17,25 +17,17 @@ class BertHTTPProxy(Process):
             from flask_compress import Compress
             from flask_cors import CORS
             from flask_json import FlaskJSON, as_json, JsonError
-            from transformer_serving.client import ConcurrentBertClient
-            from flasgger import Swagger
+            from bert_serving.client import ConcurrentBertClient
         except ImportError:
             raise ImportError('BertClient or Flask or its dependencies are not fully installed, '
                               'they are required for serving HTTP requests.'
-                              'Please use "pip install -U serving-server[http]" to install it.')
+                              'Please use "pip install -U bert-serving-server[http]" to install it.')
 
         # support up to 10 concurrent HTTP requests
         bc = ConcurrentBertClient(max_concurrency=self.args.http_max_connect,
                                   port=self.args.port, port_out=self.args.port_out,
                                   output_fmt='list', ignore_all_checks=True)
         app = Flask(__name__)
-        app.config['SWAGGER'] = {
-          'title': 'Colors API',
-          'uiversion': 3,
-          'openapi': '3.0.2'
-        }
-        swag = Swagger(app, template_file='bertApi.openapi.yaml')
-
         logger = set_logger(colored('PROXY', 'red'))
 
         @app.route('/status/server', methods=['GET'])
